# Slot: typeof


supertype

URI: [http://w3id.org/biolink/biolinkml/meta/typeof](slot_uri)
## Domain and Range

[TypeDefinition](TypeDefinition.md) -><sub>opt</sub> [TypeDefinition](TypeDefinition.md)
## Inheritance

## Children

## Used by

 * [TypeDefinition](TypeDefinition.md)
